@@ -4,7 +4,7 @@ set -eu
 declare -A PKG_MAP
 
 # workaround: for latest bindep to work, it needs to use en_US local
-export LANG=en_US.UTF-8
+export LANG=c
 
 CHECK_CMD_PKGS=(
     gcc
@@ -87,7 +87,7 @@ case ${ID,,} in
         [wget]=wget
     )
     EXTRA_PKG_DEPS=()
-    sudo -E yum updateinfo
+    sudo -E ${PKG_MANAGER} updateinfo
     if $(grep -q Fedora /etc/redhat-release); then
         EXTRA_PKG_DEPS="python-dnf redhat-rpm-config"
     fi
@@ -174,15 +174,14 @@ if [[ $(readlink -f /etc/alternatives/pip) =~ "pip3" ]]; then
     sudo -H update-alternatives --remove pip $(readlink -f /etc/alternatives/pip)
 fi
 
-if ! "${PYTHON}" -m pip > /dev/null; then
-    wget -O /tmp/get-pip.py https://bootstrap.pypa.io/3.4/get-pip.py
+if ! which pip; then
+    wget -O /tmp/get-pip.py https://bootstrap.pypa.io/3.2/get-pip.py
     sudo -H -E ${PYTHON} /tmp/get-pip.py
 fi
 
-PIP="${PYTHON} -m pip"
+PIP=$(which pip)
 
-# NOTE(dtantsur): 9.0.0 introduces --upgrade-strategy.
-sudo -H -E ${PIP} install --upgrade "pip>9.0"
+sudo -H -E ${PIP} install "pip>6.0"
 
 # upgrade setuptools, as latest version is needed to install some projects
 sudo -H -E ${PIP} install --upgrade --force setuptools
@@ -192,7 +191,7 @@ if [ "$OS_FAMILY" == "RedHat" ]; then
     sudo -H -E ${PIP} install --ignore-installed pyparsing ipaddress
 fi
 
-sudo -H -E ${PIP} install -r "$(dirname $0)/../requirements.txt" -c ${UPPER_CONSTRAINTS_FILE:-https://releases.openstack.org/constraints/upper/stein}
+sudo -H -E ${PIP} install -r "$(dirname $0)/../requirements.txt"
 
 # Install the rest of required packages using bindep
 sudo -H -E ${PIP} install bindep
